/*
Copyright (c) 2002-2011 Nokia Corporation and/or its subsidiary(-ies). All rights reserved.

Redistribution and use in source and binary forms, with or without
modification, are permitted provided that the following conditions are met:

* Redistributions of source code must retain the above copyright notice, this
 list of conditions and the following disclaimer.
* Redistributions in binary form must reproduce the above copyright notice,
 this list of conditions and the following disclaimer in the documentation
 and/or other materials provided with the distribution.
* Neither the name of Nokia Corporation nor the names of its contributors
 may be used to endorse or promote products derived from this software
 without specific prior written permission.

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

Description: 
*/ 

#ifndef __RPSGAMEENGINE_H__
#define __RPSGAMEENGINE_H__

// INCLUDES
#include "rpsappview.h"
#include "rpsGameScreens.h"
#include "commoninterfaces.h"

class CInactivityTimer;

// CLASS DECLARATION
class MEngineObserver
	{
public:
	virtual void UpdateScreen()=0;
	};
		
//-----------------------------------------------------------
class CRpsGameEngine : public CBase, public MAppViewObserver
									 
	{
public: // Construction methods

	/**
	* NewL.
	* Two-phased constructor.
	* Create a CRpsGameEngine object.
	* @aparam aObs a reference to the engine observer
	*/
	static CRpsGameEngine* NewL(MEngineObserver& aObs);

	/**
	* ~CRpsGameEngine 
	* Virtual Destructor.
	*/
	virtual ~CRpsGameEngine();

public:	//From MAppViewObserver
	/**
	 * Called by framework when application focus changes
	 * @aparam aFocus Indicates whether the focus has or has not changed
	 */
	void FocusChanged(TBool aFocus);
	
	/**
	 * Handles key events generated by the player
	 * @aparam aKeyState the key that was pressed
	 */
	void KeyEvent(TUint& aKeyState);
	
	/**
	 * Update the application view with the current game screen
	 */
	void DrawGameScreen();
	
public:	
	/**
	* Static callback method used by the periodic timer
	* Calls GameLoop()
	* @aparam aCallback pointer to the callback function
	*/
	static TInt Tick(TAny* aCallback);
	
	/**
	* Starts the heartbeat timer to drive the game loop
	*/	
	void StartHeartbeat();
	
	/**
	Stops the heartbeat time and pauses the game loop
	aTimedOut boolean indicates whether the inactivity timeout has expired
	ETrue if it has (because the user hasn't interacted with the game)
	EFalse if the heartbeat is stopping because the game has lost focus or is exiting
	*/	
	void StopHeartbeat(TBool aTimedOut = EFalse);
	
	/**
	 * Pause the game in the event of a timeout
	 */
	void PauseGame();
	
	/**
	 * Called when input is received to bring it out of pause
	 */
	void UnpauseGame();
			
private: // Construction and methods that leave

	/**
	* ConstructL
	* 2nd phase constructor.
	*/
	void ConstructL();

	/**
	* CRpsGameEngine 
	* C++ default constructor.
	* @aparam The reference to the engine observer
	*/
	CRpsGameEngine(MEngineObserver& aObs);
	
private:			
	
	/**
	* Called by the periodic timer on every heartbeat.
	* Checks user input, updates the graphics accordingly.
	*/		
	void GameLoop();
	
private:
	/**
	* The engine observer (to notify when screen updates are needed)
	*/
	MEngineObserver& iObs;
	
	/**
	* Timer for the game loop
	*/
	CPeriodic* iPeriodicTimer;
	
	/**
	* The inactivity timer
	*/
	CInactivityTimer* iInactivity;
	
	/**
	* Manages an array of game screens
	*/
	CGameScreenManager* iGameScreenMgr;
		
	};

#endif // __RPSGAMEENGINE_H__

// End of File
